@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-from matos_azure_provider.lib import factory
 from typing import Any, Dict
+from matos_azure_provider.lib import factory
 from matos_azure_provider.lib.base_provider import BaseProvider
 
 
@@ -36,4 +36,9 @@ class AzureNetwork(BaseProvider):
 
 
 def register() -> Any:
+    """Register class plugins
+
+    Returns:
+        Any: None
+    """
     factory.register("network", AzureNetwork)
